@@ -21,6 +21,7 @@ class PipelineOperator:
     OUTPUT_NAME_JSON = ""
     CONTAINTER_NAME = ""
     CONNECTION_STRING_NAME = 'STORAGE_CONNECTION_STRING'
+    STORAGE_MAP = None
 
     def __init__(self, conn_str, storage_url, container_name, map_file_name=f"storage_map_{datetime.now().strftime('%Y_%m')}.json"):
         self.logger = logging.getLogger(__name__)
@@ -32,7 +33,7 @@ class PipelineOperator:
         self.CONTAINTER_NAME = container_name
         conn_str = self._check_conn_str(
             conn_str=conn_str, storage_url=storage_url)
-        os.environ['STORAGE_CONNECTION_STRING'] = conn_str
+        os.environ[self.CONNECTION_STRING_NAME] = conn_str
         self.logger.info(
             f"### Init complete for {storage_url}, preparing auth...")
 
@@ -41,13 +42,22 @@ class PipelineOperator:
                                         container_name=self.CONTAINTER_NAME, map_file_name=self.OUTPUT_NAME_JSON)
         storage_map = container_mapper.map_container()
         container_mapper.write_map_local(storage_map)
-        map_reporter = MapReporter(storage_map=storage_map, depth=2)
-        csv_data = map_reporter.print_csv()
-        with open(self.OUTPUT_NAME_CSV, "w") as file:
-            file.write(csv_data)
+        map_reporter = MapReporter(
+            storage_map=storage_map, depth=2, output_file_name=self.OUTPUT_NAME_CSV)
+        map_reporter.write_csv_local()
+
+    def submit_pipeline_data(self):
+        from azure.storage.blob import ContainerClient
+        conn_string = os[self.CONNECTION_STRING_NAME]
+        container_client = ContainerClient.from_connection_string(
+            conn_str=conn_string, container_name=self.CONTAINTER_NAME)
+        for file_name in [self.OUTPUT_NAME_CSV, self.OUTPUT_NAME_JSON]:
+            with open(file_name, 'r') as file:
+                file_contents = file.read()
+                blob_client = container_client.get_blob_client(file_name)
+                blob_client.upload_blob(file_contents)
 
     def _check_conn_str(self, conn_str, storage_url):
-
         for kw in ['BlobEndpoint', 'QueueEndpoint', 'TableEndPoint', 'FileEndPoint', 'SharedAccessSignature', 'sv']:
             if kw not in conn_str:
                 token = ""
@@ -74,7 +84,13 @@ if __name__ == '__main__':
     parser.add_argument('--container_name', type=str, required=True)
     parser.add_argument('--map_name', type=str, required=False,
                         default=f"storage_map_{datetime.now().strftime('%Y_%m')}.json")
+    parser.add_argument('--publish_metrics', type=bool, default=False, action='store_true',
+                        help="Whether or not to publish metrics generated to the storage container specified in args")
+    parser.add_argument('--generate_metrics', type=bool, default=True, action='store_true', help="Whether or not to generate new metrics files using provided filenames")
     args = parser.parse_args()
     pipeline_operator = PipelineOperator(conn_str=args.conn_str, storage_url=args.storage_url,
                                          container_name=args.container_name, map_file_name=args.map_name)
-    pipeline_operator.collect_pipeline_data()
+    if args.generate_metrics:
+        pipeline_operator.collect_pipeline_data()
+    if args.publish_metrics:
+        pipeline_operator.submit_pipeline_data()
