@@ -150,9 +150,13 @@ class ContainerMap:
     def delete_map(self):
         """Deletes the storage map from the blob storage container if it exists
         """
-        blob_client = self.container_client.get_blob_client(self.MAP_FILE_NAME)
-        if blob_client.exists():
-            blob_client.delete_blob()
+        try:
+            self.logger.info(f"Attempting to delete {self.MAP_FILE_NAME}")
+            blob_client = self.container_client.get_blob_client(self.MAP_FILE_NAME)
+            if blob_client.exists():
+                blob_client.delete_blob()
+        except Exception as e:
+            self.logger.warn(f"Failed to delete {self.MAP_FILE_NAME} before mapping container:\n{e}")
 
 
 class FileShareMap:
